from datetime import datetime


class RandomStr:
    def geTimeStr(self, pre="", strf="%Y%m%d%H%M%S"):
        time_str = datetime.now().strftime(strf)
        return '{}{}'.format(pre, time_str)


class Generic:
    @classmethod
    def from_dict(cls, dict):
        obj = cls()
        obj.__dict__.update(dict)
        return obj


class JsonSerializable(object):

    def toDict(self):
        for key, value in self.__dict__.items():
            if isinstance(value, JsonSerializable) and hasattr(value, 'toDict'):
                self.__dict__[key] = value.toDict()
        return self.__dict__

    def toJson(self):
        if isinstance(self, JsonSerializable) and hasattr(self, 'toDict'):
            return json.dumps(self.toDict(), ensure_ascii=False)
        else:
            return json.dumps(self.__dict__, ensure_ascii=False)


import psycopg2


class DBConnect(object):
    def __init__(self, dbConfig):
        self.db_conf = dbConfig
        # 获取连接对象
        self.conn = psycopg2.connect(
            host=self.db_conf.host,
            port=self.db_conf.port,
            user=self.db_conf.user,
            password=self.db_conf.password,
            database=self.db_conf.database
        )
        # 获取数据的游标
        self.cur = self.conn.cursor()

    def close_connect(self):
        # 关闭数据连接
        # 游标关闭
        self.cur.close()
        # 连接对象关闭
        self.conn.close()

    def delete_user(self, username):
        """删除指定的对象数据"""
        sqlStr = "delete from sys_user where \"name\" like '{}%'".format(username)
        self.cur.execute(sqlStr)
        self.conn.commit()



import base64
from hashlib import md5

from Crypto.Cipher import AES
from cryptography.hazmat.primitives import padding
from cryptography.hazmat.primitives.ciphers import algorithms

'''
encrypt_md5 加密
AES/CBC/PKCS7Padding 加密
环境需求:
pip3 install pycryptodome
'''


def encrypt_md5(str_data):
    # 创建md5对象
    new_md5 = md5()
    # 这里必须用encode()函数对字符串进行编码，不然会报 TypeError: Unicode-objects must be encoded before hashing
    new_md5.update(str_data.encode(encoding='utf-8'))
    # 加密
    return new_md5.hexdigest()


class AesCrypt(object):

    def __init__(self, key='0000000000000000', iv='0000000000000000'):
        self.key = key.encode('utf-8')
        self.mode = AES.MODE_CBC
        self.iv = iv.encode('utf-8')
        # block_size 128位

    # 加密函数，如果text不足16位就用空格补足为16位，
    # 如果大于16但是不是16的倍数，那就补足为16的倍数。
    def encrypt(self, text):
        cryptor = AES.new(self.key, self.mode, self.iv)
        text = text.encode('utf-8')

        # 这里密钥key 长度必须为16（AES-128）,24（AES-192）,或者32 （AES-256）Bytes 长度
        # 目前AES-128 足够目前使用

        text = self.pkcs7_padding(text)

        cipher_text = cryptor.encrypt(text)

        return base64.b64encode(cipher_text)

    @staticmethod
    def pkcs7_padding(data):
        if not isinstance(data, bytes):
            data = data.encode()

        padder = padding.PKCS7(algorithms.AES.block_size).padder()

        padded_data = padder.update(data) + padder.finalize()

        return padded_data


def encrypt_AES(timestamps, pwd):
    md5_str = encrypt_md5('{}{}'.format(timestamps, 'fd#O@7Ej0.U4P2^i'))
    key = md5_str[:16]
    iv = md5_str[16:]
    pc = AesCrypt(key, iv)  # 初始化密钥
    en_pwd = pc.encrypt(pwd).decode()
    return en_pwd


# 加密(系统加密后：QIZ2JGAE7o3jEOtuQzutqw==)
if __name__ == '__main__':
    encrypt_str = encrypt_AES('1615877310430', 'zsy@1221')
    print(encrypt_str)



"""
文件读写。ExcelHandler读写excel。
"""
import os
import shutil
from datetime import datetime


def find_file(start_dir, file_name):
    doc_list = os.listdir(start_dir)
    for doc in doc_list:
        doc_path = os.path.join(start_dir, doc)
        if os.path.isdir(doc_path):
            result = find_file(doc_path, file_name)
            if result:
                return result
        else:
            if doc == file_name:
                return doc_path


def last_file(path):
    """找到最新的文件或文件夹"""
    # 列出目录下所有的文件
    doc_list = os.listdir(path)
    # 对文件修改时间进行升序排列
    doc_list.sort(key=lambda fn: os.path.getmtime(path + '\\' + fn))
    # 获取最新修改时间的文件
    filetime = datetime.fromtimestamp(os.path.getmtime(path + '\\' + doc_list[-1]))
    # 获取文件所在目录
    filepath = os.path.join(path, doc_list[-1])
    print("最新修改的文件(夹)：" + doc_list[-1])
    print("时间：" + filetime.strftime('%Y-%m-%d %H-%M-%S'))
    return filepath


def move_file(old_path, new_path):
    print(old_path)
    print(new_path)
    fileList = os.listdir(old_path)  # 列出该目录下的所有文件,listdir返回的文件列表是不包含路径的。
    print(fileList)
    for file in fileList:
        if file.startswith('__init__'):
            continue
        src = os.path.join(old_path, file)
        dst = os.path.join(new_path, file)
        print('src:', src)
        print('dst:', dst)
        shutil.move(src, dst)


def del_file(path):
    """删除指定文件夹的所有文件"""
    ls = os.listdir(path)
    for i in ls:
        if i.startswith('__init__'):
            continue
        c_path = os.path.join(path, i)
        if os.path.isdir(c_path):
            del_file(c_path)
        else:
            print('delete file:%s' % c_path)
            os.remove(c_path)





import paramiko


class SSHClient:
    def __init__(self, host, user, password):
        self.sshClient = paramiko.SSHClient()
        self.sshClient.set_missing_host_key_policy(paramiko.AutoAddPolicy())  # 允许连接不在know_hosts文件中的主机
        self.sshClient.connect(host, 22, user, password, look_for_keys=False)

    def execmd(self, cmdStr):
        """
        :param cmdStr: 需要输入的命令
        """
        stdin, stdout, stderr = self.sshClient.exec_command(cmdStr)
        return stdout

    def close(self):
        self.sshClient.close()



#!/usr/bin/env python
# -*- coding:utf-8 -*-

from setuptools import setup, find_packages

setup(
    name="oneSports-TestCommon",  # 这里是pip项目发布的名称
    version="2.1.7",  # 版本号，数值大的会优先被pip
    keywords=["pip", "TestCommon", "oneSports"],
    description="An auto test common module",
    long_description="An auto test common module",
    license="MIT Licence",

    url="http://gitlab.onesport.com.cn/auto_test/common.git",  # 项目相关文件地址，一般是github
    author="zsy",
    author_email="501971693@qq.com",

    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=["cryptography", "pycryptodome", "psycopg2-binary", "paramiko"]  # 这个项目需要的第三方库
)
